meneco-gui
==========

A graphical user interface for meneco

Installation
------------

meneco-gui is implemented using PyQt. Unfortunately PyQt4 is not as easily installed via pip.
So you first need to get your hands  dirty and install it manually.
If your distribution does not provide PyQt4 packages you can find instructions for installing PyQt4 here_.

You can then install meneco-gui by running::

	$ pip install --user meneco-gui

The executable scripts can then be found in ~/.local/bin.


Usage
-----

Typical usage is::

	$ meneco-gui.py 

.. _here: http://pyqt.sourceforge.net/Docs/PyQt4/installation.html
